# NACE_clean

This is a copy from the TX projects of the NACE code I was cleaning/tidying and checking before I started to  majorly divert it from Patrick's work.

It is here in case I need to revert back to it.

